==> haskell-shakespeare-2.0.9-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.9
id: shakespeare-2.0.9-5XiDCldtQ8x7HOyhvWsW1I
key: shakespeare-2.0.9-5XiDCldtQ8x7HOyhvWsW1I
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                Text.IndentToBrace Text.CssCommon
abi: 11a5d79d76e4718900c4758e6d8aaa5e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/shakespeare-2.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/shakespeare-2.0.9
data-dir: /usr/share/arm-linux-ghc-8.0.1/shakespeare-2.0.9
hs-libraries: HSshakespeare-2.0.9-5XiDCldtQ8x7HOyhvWsW1I
depends:
    aeson-0.11.2.0-FbOoMAnyGWNAFaN63GUEkg base-4.9.0.0
    blaze-html-0.8.1.1-BhhXJch8Gg8D1ETUvb8oFp
    blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d bytestring-0.10.8.1
    containers-0.5.7.1 directory-1.2.6.2
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf ghc-prim-0.5.0.0
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    scientific-0.3.4.7-5pvfIBiHUcSGJtkaWTYnEJ template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.9-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.9
id: shakespeare-2.0.9-F2PFp5uLZOGGTgAfGGNDEx
key: shakespeare-2.0.9-F2PFp5uLZOGGTgAfGGNDEx
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                Text.IndentToBrace Text.CssCommon
abi: b4cfc5a956775d34c586b45a5608725f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/shakespeare-2.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/shakespeare-2.0.9
data-dir: /usr/share/arm-linux-ghc-8.0.1/shakespeare-2.0.9
hs-libraries: HSshakespeare-2.0.9-F2PFp5uLZOGGTgAfGGNDEx
depends:
    aeson-0.11.2.0-FpCNsdqaa7PINk2PVkQvbE base-4.9.0.0
    blaze-html-0.8.1.1-BhhXJch8Gg8D1ETUvb8oFp
    blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d bytestring-0.10.8.1
    containers-0.5.7.1 directory-1.2.6.2
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf ghc-prim-0.5.0.0
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    scientific-0.3.4.8-7EVzQKtKSWIF0S6OhCJfZU template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
